@@ -7,5 +7,5 @@ class EnumValidator:
 
     def validate(self, ctx, value):
         TypeValidator(str).validate(ctx, value)
-        if value not in self._enum.__members__:
-            ctx.error("value is not a valid member of enum", enum = str(self._enum), value = value)
\ No newline at end of file
+        if value not in self._enum:
+            ctx.error("value is not a valid member", value = value)
\ No newline at end of file
